convert_to_raster_era5land <- function(accum, vars, region) {
  for (i in accum){
    for (var in vars){
  
      data <- readRDS(paste0("data/", region, "_", var, "_", i, ".rds"))
  
      # Assign latitude and longitude coordinates from data
      lon <- data$coords$longitude
      lat <- data$coords$latitude
  
      # Set time variables
      nmonths <- data$dims[["time"]]
      nyears <- data$dims[["syear"]]
      ntimes <- nyears * nmonths
  
      # Transform multidimensional array into list of rasters
      out <- NULL
      for (x in 1:ntimes){
  
        # Calculate i and j from x
        m <- ((x - 1) %% nmonths) + 1
        y <- (((x - 1) %/% nmonths)) %% nyears + 1
  
        # Extract date
        b <- substr(data$attrs$Dates[x], 1, 10)
  
        if (is.na(b)) {
          print(paste(x, b))
          next
        }
        # Extract array of values for year-month-day combination
        a <-  data$data[1, 1, m, y, 1, , ] #month, year, day
  
        # Convert to a raster
        out[[b]] <- raster::raster(a,
                                   xmn = min(lon), xmx = max(lon),
                                   ymn = min(lat), ymx = max(lat))
        # Assign CRS
        raster::crs(out[[b]]) <- "+init=epsg:4326"
        print(x)
      }
  
      # Convert list of rasters into stack
      stack_name <- paste0(var, i, "_raster")
      assign(stack_name, NULL)
      assign(stack_name, raster::stack(out))
      print(paste0("calculated ", var, i))
  
      saveRDS(get(stack_name), paste0("data/", region, "_", var, "_", i, "_stack.rds"))
    }
  }
}

convert_to_raster_input_variables <- function(vars, region) {
  for (var in vars){
    data <- readRDS(paste0("data/", region, "_", var, ".rds"))

    # Assign latitude and longitude coordinates from data
    lon <- data$coords$longitude
    lat <- data$coords$latitude

    # Set time variables
    nmonths <- data$dims[["time"]]
    nyears <- data$dims[["syear"]]
    ntimes <- nyears * nmonths

    # Transform multidimensional array into list of rasters
    out <- NULL
    for (x in 1:ntimes){

      # Calculate i and j from x
      m <- ((x - 1) %% nmonths) + 1
      y <- (((x - 1) %/% nmonths)) %% nyears + 1

      # Extract date
      b <- substr(data$attrs$Dates[x], 1, 10)

      if (is.na(b)) {
        print(paste(x, b))
        next
      }
      # Extract array of values for year-month-day combination
      a <-  data$data[1, 1, m, y, 1, , ] #month, year, day

      # Convert to a raster
      out[[b]] <- raster::raster(a,
                                 xmn = min(lon), xmx = max(lon),
                                 ymn = min(lat), ymx = max(lat))
      # Assign CRS
      raster::crs(out[[b]]) <- "+init=epsg:4326"
      print(x)
    }

    # Convert list of rasters into stack
    stack_name <- paste0(var, "_raster")
    assign(stack_name, NULL)
    assign(stack_name, raster::stack(out))
    print(paste0("calculated ", var))

    saveRDS(get(stack_name), paste0("data/", region, "_", var, "_stack.rds"))
  }
  
}

convert_to_raster_population_era5land <- function(region, vars, accum) {
  population <- readRDS("../00_population/data/population.rds")
  rr <- raster::rasterFromXYZ(population[, c("x", "y", "population")])
  rm(population)

  spei6_raster <- readRDS(paste0("data/", region, "_", vars[1], "_", accum[1], "_stack.rds"))
  spei6_raster <- spei6_raster[[1]]

  extent(rr) <- extent(spei6_raster)
  crs(rr) <- crs(spei6_raster)
  rr_regrid <- raster::resample(rr, spei6_raster, method = "bilinear")
  rm(rr, spei6_raster)
  saveRDS(rr_regrid, paste0("data/", region, "_population_stack.rds"))
}